@@ -44,7 +44,7 @@ class ArkitektWidget(QtWidgets.QWidget):
 
         self.helper = StageHelper(napari_viewer)
 
-        self.magic_bar = NapariMagicBar(self.fakts, self.herre, self.agent, parent=self)
+        self.magic_bar = NapariMagicBar(self.fakts, self.herre, self.agent, parent=self, darkMode=True)
 
         self.agent.register(self.really_show, widgets={"rep": MY_TOP_REPRESENTATIONS}, on_assign=self.really_show)
         self.agent.register(self.upload, widgets={"sample": MY_TOP_SAMPLES}, on_assign=self.upload)
